"use strict";
var _AiChatService_sessionModel;
Object.defineProperty(exports, "__esModule", { value: true });
exports.AiChatService = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const command_1 = require("@opensumi/ide-core-browser/lib/ai-native/command");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const ai_native_1 = require("@opensumi/ide-core-common/lib/ai-native");
const reporter_1 = require("@opensumi/ide-core-common/lib/ai-native/reporter");
const ide_editor_1 = require("@opensumi/ide-editor");
const workbench_editor_service_1 = require("@opensumi/ide-editor/lib/browser/workbench-editor.service");
const common_1 = require("../common");
const chat_manager_service_1 = require("./chat-manager.service");
const msg_stream_manager_1 = require("./model/msg-stream-manager");
const menu_bar_service_1 = require("./override/layout/menu-bar/menu-bar.service");
let AiChatService = class AiChatService extends ide_core_common_1.Disposable {
    get latestSessionId() {
        return this._latestSessionId;
    }
    get currentEditor() {
        return this.editorService.currentEditor;
    }
    get sessionModel() {
        return tslib_1.__classPrivateFieldGet(this, _AiChatService_sessionModel, "f");
    }
    constructor() {
        super();
        this._onChatMessageLaunch = new ide_core_common_1.Emitter();
        this.onChatMessageLaunch = this._onChatMessageLaunch.event;
        this._onChangeSessionId = new ide_core_common_1.Emitter();
        this.onChangeSessionId = this._onChangeSessionId.event;
        this._onInlineChatVisible = new ide_core_common_1.Emitter();
        this.onInlineChatVisible = this._onInlineChatVisible.event;
        _AiChatService_sessionModel.set(this, void 0);
        this.cancelIndicator = new ide_core_common_1.CancellationTokenSource();
        this.cancelIndicatorChatView = new ide_core_common_1.CancellationTokenSource();
        tslib_1.__classPrivateFieldSet(this, _AiChatService_sessionModel, this.chatManagerService.startSession(), "f");
    }
    launchChatMessage(data) {
        this.commandService.executeCommand(command_1.AI_CHAT_PANEL_TOGGLE_VISIBLE.id, true);
        this._onChatMessageLaunch.fire(data);
    }
    launchInlineChatVisible(value) {
        this._onInlineChatVisible.fire(value);
    }
    cancelToken() {
        this.cancelIndicator.cancel();
        this.cancelIndicator = new ide_core_common_1.CancellationTokenSource();
    }
    cancelChatViewToken() {
        this.cancelIndicatorChatView.cancel();
        this.cancelIndicatorChatView = new ide_core_common_1.CancellationTokenSource();
    }
    async destroyStreamRequest(sessionId) {
        if (this.aiBackService.destroyStreamRequest) {
            await this.aiBackService.destroyStreamRequest(sessionId);
            this.msgStreamManager.sendDoneStatue();
        }
    }
    async switchAIService(input, prompt = '') {
        let type = reporter_1.AISerivceType.GPT;
        let message = prompt || input;
        if (input.startsWith(common_1.InstructionEnum.aiSumiKey)) {
            type = reporter_1.AISerivceType.Sumi;
            message = input.split(common_1.InstructionEnum.aiSumiKey)[1];
            return { type, message };
        }
        if (input.startsWith(common_1.InstructionEnum.aiTestKey)) {
            type = reporter_1.AISerivceType.Test;
            message = input.split(common_1.InstructionEnum.aiTestKey)[1];
            if (!prompt) {
                prompt = this.generateTestCodePrompt(message);
            }
            return { type, message: prompt };
        }
        if (input.startsWith(common_1.InstructionEnum.aiOptimzeKey)) {
            type = reporter_1.AISerivceType.Optimize;
            message = input.split(common_1.InstructionEnum.aiOptimzeKey)[1];
            if (!prompt) {
                prompt = this.optimzeCodePrompt(message);
            }
            return { type, message: prompt };
        }
        if (input.startsWith(common_1.InstructionEnum.aiExplainKey)) {
            type = reporter_1.AISerivceType.Explain;
            message = input.split(common_1.InstructionEnum.aiExplainKey)[1];
            if (!prompt) {
                prompt = this.explainCodePrompt(message);
            }
            return { type, message: prompt };
        }
        if (input.startsWith(common_1.InstructionEnum.aiRunKey)) {
            return { type: reporter_1.AISerivceType.Run, message: prompt };
        }
        // if (input.startsWith(InstructionEnum.aiSearchDocKey)) {
        //   type = AISerivceType.SearchDoc;
        //   message = input.split(InstructionEnum.aiSearchDocKey)[1];
        //   return { type, message };
        // }
        // if (input.startsWith(InstructionEnum.aiSearchCodeKey)) {
        //   type = AISerivceType.SearchCode;
        //   message = input.split(InstructionEnum.aiSearchCodeKey)[1];
        //   return { type, message };
        // }
        return { type, message };
    }
    generateTestCodePrompt(message = '') {
        return `为以下代码写单测：\n\`\`\`\n ${message}\n\`\`\``;
    }
    optimzeCodePrompt(message = '') {
        return `优化以下代码：\n\`\`\`\n ${message}\`\`\``;
    }
    // 解释当前文件的代码或者选中的某个代码片段的 prompt，也可以用于对选中的代码加上用户的描述进行解释
    explainCodePrompt(message = '') {
        var _a;
        if (!this.currentEditor) {
            return '';
        }
        const currentUri = this.currentEditor.currentUri;
        if (!currentUri) {
            return '';
        }
        const displayName = currentUri.displayName;
        const fsPath = currentUri.codeUri.fsPath;
        const content = this.currentEditor.monacoEditor.getValue();
        const selectionContent = ((_a = this.currentEditor.monacoEditor.getModel()) === null || _a === void 0 ? void 0 : _a.getValueInRange(this.currentEditor.monacoEditor.getSelection())) ||
            '';
        let messageWithPrompt = '';
        /**
         * 分三种情况
         * 1. 没打开任意一个文件，则提供当前文件目录树给出当前项目的解释。如果用户有 prompt，则在最后带上
         * 2. 没选中任意代码，则解释当前打开的代码文件（文件路径、代码）
         * 3. 选中任意代码，则带上当前文件信息（文件路径、代码）和选中片段
         * 4. 打开当前文件，用户如果有 prompt，则在最后带上。此时如果有选中代码片段，则带上，没有则带上文件代码
         */
        if (!this.currentEditor || !this.currentEditor.currentUri) {
            //
        }
        if (!selectionContent) {
            messageWithPrompt = `这是 ${displayName} 文件, 位置是在 ${fsPath}, 代码内容是 \`\`\`\n${content}\n\`\`\`。向我解释这个代码内容的意图`;
        }
        if (selectionContent) {
            messageWithPrompt = `这是 ${displayName} 文件, 位置是在 ${fsPath}, 解释一下这段代码的意图: \`\`\`${selectionContent} \`\`\``;
        }
        if (message.trim()) {
            if (selectionContent) {
                messageWithPrompt = `这是 ${displayName} 文件，我会提供给你代码片段以及我的问题, 你需要根据我给的代码片段来解释我的问题。我提供的代码片段是: \`\`\`\n${selectionContent}\n\`\`\`，我的问题是: "${message}" `;
            }
            else {
                messageWithPrompt = `解释下面的代码: "${message}" `;
            }
        }
        return messageWithPrompt;
    }
    /**
     * by backend service
     * @param message
     */
    onMessage(message, sessionId) {
        try {
            const msgObj = JSON.parse(message);
            if (msgObj.id && msgObj.choices) {
                const { id, choices } = msgObj;
                this.msgStreamManager.recordMessage(id, choices[0]);
            }
            else {
                this.msgStreamManager.sendErrorStatue();
            }
            if (msgObj.errorCode && sessionId) {
                const errMsg = msgObj.errorMsg || '';
                this.aiReporter.end(sessionId, {
                    message: errMsg,
                    success: false,
                });
            }
        }
        catch (error) {
            throw new Error(`onMessage error: ${error}`);
        }
    }
    async messageWithStream(input, options = {}, sessionId) {
        this.msgStreamManager.setCurrentSessionId(sessionId);
        this.msgStreamManager.sendThinkingStatue();
        await this.aiBackService.requestStream(input, Object.assign(Object.assign({}, options), { sessionId }), this.cancelIndicatorChatView.token);
    }
    async message(input, options = {}) {
        const res = await this.aiBackService.request(input, options, this.cancelIndicatorChatView.token);
        if (res.isCancel) {
            return null;
        }
        if (res.errorCode !== 0) {
            return res.errorMsg || '';
        }
        else {
            return res.data || '';
        }
    }
    async searchDoc(input, sessionId) {
        return this.messageWithStream(input, { type: 'searchDoc' }, sessionId);
    }
    async searchCode(input, sessionId) {
        return this.messageWithStream(input, { type: 'searchCode' }, sessionId);
    }
    setLatestSessionId(id) {
        this._latestSessionId = id;
        this._onChangeSessionId.fire(id);
    }
    createRequest(input, agentId, command) {
        return this.chatManagerService.createRequest(tslib_1.__classPrivateFieldGet(this, _AiChatService_sessionModel, "f").sessionId, input, agentId, command);
    }
    sendRequest(request, regenerate = false) {
        return this.chatManagerService.sendRequest(tslib_1.__classPrivateFieldGet(this, _AiChatService_sessionModel, "f").sessionId, request, regenerate);
    }
    cancelRequest() {
        this.chatManagerService.cancelRequest(tslib_1.__classPrivateFieldGet(this, _AiChatService_sessionModel, "f").sessionId);
    }
    clearSessionModel() {
        this.chatManagerService.clearSession(tslib_1.__classPrivateFieldGet(this, _AiChatService_sessionModel, "f").sessionId);
        tslib_1.__classPrivateFieldSet(this, _AiChatService_sessionModel, this.chatManagerService.startSession(), "f");
    }
    dispose() {
        var _a;
        (_a = tslib_1.__classPrivateFieldGet(this, _AiChatService_sessionModel, "f")) === null || _a === void 0 ? void 0 : _a.dispose();
        super.dispose();
    }
};
_AiChatService_sessionModel = new WeakMap();
tslib_1.__decorate([
    (0, di_1.Autowired)(ai_native_1.AiBackSerivcePath),
    tslib_1.__metadata("design:type", Object)
], AiChatService.prototype, "aiBackService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.PreferenceService),
    tslib_1.__metadata("design:type", Object)
], AiChatService.prototype, "preferenceService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_editor_1.WorkbenchEditorService),
    tslib_1.__metadata("design:type", workbench_editor_service_1.WorkbenchEditorServiceImpl)
], AiChatService.prototype, "editorService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(msg_stream_manager_1.MsgStreamManager),
    tslib_1.__metadata("design:type", msg_stream_manager_1.MsgStreamManager)
], AiChatService.prototype, "msgStreamManager", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(menu_bar_service_1.AiMenubarService),
    tslib_1.__metadata("design:type", menu_bar_service_1.AiMenubarService)
], AiChatService.prototype, "aiMenubarService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_common_1.CommandService),
    tslib_1.__metadata("design:type", Object)
], AiChatService.prototype, "commandService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(reporter_1.IAIReporter),
    tslib_1.__metadata("design:type", Object)
], AiChatService.prototype, "aiReporter", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IChatManagerService),
    tslib_1.__metadata("design:type", chat_manager_service_1.ChatManagerService)
], AiChatService.prototype, "chatManagerService", void 0);
AiChatService = tslib_1.__decorate([
    (0, di_1.Injectable)(),
    tslib_1.__metadata("design:paramtypes", [])
], AiChatService);
exports.AiChatService = AiChatService;
//# sourceMappingURL=ai-chat.service.js.map