"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatInput = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const react_1 = tslib_1.__importStar(require("react"));
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const components_1 = require("@opensumi/ide-core-browser/lib/components");
const ai_native_1 = require("@opensumi/ide-core-browser/lib/components/ai-native");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const command_service_1 = require("@opensumi/ide-editor/lib/browser/monaco-contrib/command/command.service");
const common_1 = require("../../common");
const styles = tslib_1.__importStar(require("./components.module.less"));
const MAX_WRAPPER_HEIGHT = 160;
const SHOW_EXPEND_HEIGHT = 68;
const INSTRUCTION_BOTTOM = 8;
const PLACEHOLDER = {
    DEFAULT: '可以问我任何问题，或键入主题 ”/“ ',
    CODE: '请输入或者粘贴代码',
};
const VALUE_START_WITH_THEME = /^\/(\s?)(ide|explain|comments|test|searchdoc|run|optimize)\s/i;
const Block = ({ icon, name, onClick, text, agentId, command, selectedAgentId, }) => (react_1.default.createElement("div", { className: styles.block, onClick: onClick },
    icon && react_1.default.createElement(ai_native_1.EnhanceIcon, { className: icon }),
    name && react_1.default.createElement("span", { className: styles.name }, name),
    text && react_1.default.createElement("span", { className: styles.text }, text),
    !selectedAgentId && agentId && command && react_1.default.createElement("span", { className: styles.agent_label },
        "@",
        agentId)));
// 指令列表
const optionsList = [
    {
        name: common_1.InstructionEnum.aiExplainKey,
        text: '解释代码',
    },
    {
        name: common_1.InstructionEnum.aiTestKey,
        text: '生成单测',
    },
    {
        name: common_1.InstructionEnum.aiOptimzeKey,
        text: '优化代码',
    },
    {
        name: common_1.InstructionEnum.aiSumiKey,
        text: '执行 IDE 相关命令',
    },
    // {
    //   name: InstructionEnum.aiSearchDocKey,
    //   text: '搜索文档内容',
    // },
    // {
    //   name: InstructionEnum.aiSearchCodeKey,
    //   text: '搜索代码仓库中的内容',
    // },
];
// 指令命令激活组件
const InstructionOptions = ({ onClick, bottom, trigger, agentId: selectedAgentId }) => {
    const [commonlyUsed, setCommonlyUsed] = (0, react_1.useState)([]);
    const [options, setOptions] = (0, react_1.useState)([]);
    const chatAgentService = (0, ide_core_browser_1.useInjectable)(common_1.IChatAgentService);
    (0, react_1.useEffect)(() => {
        if (trigger === '@') {
            setOptions(chatAgentService.getAgents().map((a) => ({
                name: `@${a.id} `,
                text: a.metadata.description,
                command: '',
                agentId: a.id,
            })));
        }
        else {
            setOptions([
                ...optionsList,
                ...chatAgentService.getCommands().map((c) => ({
                    name: `/ ${c.name} `,
                    text: c.description,
                    command: c.name,
                    agentId: c.agentId,
                })),
            ].filter((item) => !selectedAgentId || item.agentId === selectedAgentId));
        }
    }, []);
    const handleClick = (0, react_1.useCallback)((name, agentId, command) => {
        if (onClick) {
            onClick(name || '', agentId, command);
        }
    }, [onClick]);
    return (react_1.default.createElement("div", { className: styles.instruction_options_container, style: { bottom: bottom + 'px' } },
        react_1.default.createElement("div", { className: styles.options },
            react_1.default.createElement("ul", null, options.map(({ icon, name, text, agentId, command }) => (react_1.default.createElement("li", { key: `${agentId || ''}-${name}`, onMouseDown: () => handleClick(name, agentId, command) },
                react_1.default.createElement(Block, { icon: icon, name: name, text: text, agentId: agentId, command: command, selectedAgentId: selectedAgentId })))))),
        commonlyUsed.length > 0 && (react_1.default.createElement("div", { className: styles.commonly_used },
            react_1.default.createElement("span", null, "\u5E38\u7528\u6307\u4EE4\uFF1A"),
            commonlyUsed.map(({ icon, name }, i) => (react_1.default.createElement(Block, { key: i, icon: icon, name: name })))))));
};
const ThemeWidget = ({ themeBlock }) => (react_1.default.createElement("div", { className: styles.theme_container },
    react_1.default.createElement("div", { className: styles.theme_block }, themeBlock)));
const AgentWidget = ({ agentId, command }) => (react_1.default.createElement("div", { className: styles.theme_container },
    react_1.default.createElement("div", { className: styles.theme_block, style: { marginRight: 4 } },
        "@",
        agentId),
    command && react_1.default.createElement("div", { className: styles.theme_block },
        "/ ",
        command)));
// 指令命令激活组件
exports.ChatInput = react_1.default.forwardRef((props, ref) => {
    const { onSend, onValueChange, enableOptions = false, disabled = false, defaultHeight = 32, autoFocus, setTheme, theme, setAgentId, agentId: propsAgentId, defaultAgentId, setCommand, command, } = props;
    const agentId = propsAgentId || defaultAgentId;
    const [value, setValue] = (0, react_1.useState)(props.value || '');
    const [isShowOptions, setIsShowOptions] = (0, react_1.useState)(false);
    const [wrapperHeight, setWrapperHeight] = (0, react_1.useState)(defaultHeight);
    const inputRef = (0, react_1.useRef)(null);
    const [focus, setFocus] = (0, react_1.useState)(false);
    const [showExpand, setShowExpand] = (0, react_1.useState)(false);
    const [isExpand, setIsExpand] = (0, react_1.useState)(false);
    const instructionRef = (0, react_1.useRef)(null);
    const [placeholder, setPlaceHolder] = (0, react_1.useState)(PLACEHOLDER.DEFAULT);
    const monacoCommandRegistry = (0, ide_core_browser_1.useInjectable)(command_service_1.MonacoCommandRegistry);
    const chatAgentService = (0, ide_core_browser_1.useInjectable)(common_1.IChatAgentService);
    const currentAgentIdRef = (0, ide_core_browser_1.useLatest)(agentId);
    (0, react_1.useImperativeHandle)(ref, () => ({
        setInputValue: (v) => {
            setValue(v);
            setTimeout(() => {
                var _a;
                (_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
            }, 120);
        },
    }));
    (0, react_1.useEffect)(() => {
        if (props.value !== value) {
            setValue(props.value || '');
        }
    }, [props.value]);
    (0, react_1.useEffect)(() => {
        var _a;
        setTheme(props.theme || '');
        (_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        if (theme === common_1.InstructionEnum.aiTestKey ||
            theme === common_1.InstructionEnum.aiExplainKey ||
            theme === common_1.InstructionEnum.aiOptimzeKey) {
            setPlaceHolder(PLACEHOLDER.CODE);
        }
        else {
            setPlaceHolder(PLACEHOLDER.DEFAULT);
        }
    }, [props.theme]);
    (0, react_1.useEffect)(() => {
        acquireOptionsCheck(props.theme || '');
    }, [props.theme]);
    (0, react_1.useEffect)(() => {
        var _a;
        if (inputRef && autoFocus) {
            (_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        }
    }, [inputRef, autoFocus, props.value]);
    (0, react_1.useEffect)(() => {
        if (enableOptions) {
            if ((value === '/' || (value === '@' && chatAgentService.getAgents().length > 0)) && !isExpand) {
                setIsShowOptions(true);
            }
            else {
                setIsShowOptions(false);
            }
        }
        const match = value.match(VALUE_START_WITH_THEME);
        if (match) {
            const matchValue = match[0];
            const matchString = match[2].toLowerCase();
            const resValue = value.replace(matchValue, '');
            const matchTheme = Object.values(common_1.InstructionEnum).find((v) => v.trim().slice(2).toLowerCase() === matchString ? true : false);
            if (matchTheme) {
                setValue(resValue);
                setTheme(matchTheme);
                return;
            }
        }
        if (chatAgentService.getAgents().length) {
            const parsedInfo = chatAgentService.parseMessage(value, currentAgentIdRef.current);
            if (parsedInfo.agentId || parsedInfo.command) {
                setTheme('');
                setValue(parsedInfo.message);
                if (parsedInfo.agentId) {
                    setAgentId(parsedInfo.agentId);
                }
                if (parsedInfo.command) {
                    setCommand(parsedInfo.command);
                }
            }
        }
        setTimeout(() => {
            // 自适应高度
            if (inputRef && inputRef.current && value && !isExpand) {
                inputRef.current.style.height = 0 + 'px';
                const scrollHeight = inputRef.current.scrollHeight;
                inputRef.current.style.height = Math.min(scrollHeight, MAX_WRAPPER_HEIGHT) + 'px';
                const wapperHeight = Math.min(scrollHeight + 12, MAX_WRAPPER_HEIGHT);
                setWrapperHeight(wapperHeight);
                if (wapperHeight > 68) {
                    setShowExpand(true);
                }
                else {
                    setShowExpand(false);
                }
            }
        });
    }, [inputRef, value, enableOptions]);
    (0, react_1.useEffect)(() => {
        if (!value) {
            setWrapperHeight(defaultHeight);
            setShowExpand(false);
            setIsExpand(false);
        }
    }, [value, wrapperHeight]);
    const handleInputChange = (0, react_1.useCallback)((value) => {
        setValue(value);
        if (onValueChange) {
            onValueChange(value);
        }
    }, []);
    const handleSend = (0, react_1.useCallback)(() => {
        var _a;
        if (disabled) {
            return;
        }
        // 支持 command 不传内容
        if (agentId && (value.trim() || command)) {
            onSend(value, agentId, command);
            setValue('');
            setTheme('');
            setAgentId('');
            setCommand('');
            return;
        }
        const editor = monacoCommandRegistry.getActiveCodeEditor();
        let selectCode;
        if (editor) {
            const selection = editor.getSelection();
            if (selection) {
                selectCode = (_a = editor.getModel()) === null || _a === void 0 ? void 0 : _a.getValueInRange(selection);
            }
        }
        let preText = '';
        if (theme) {
            preText = theme;
        }
        if (value.trim() && onSend) {
            setValue('');
            onSend(preText + value);
            setTheme('');
            return;
        }
        if (!value.trim() && theme === common_1.InstructionEnum.aiSumiKey) {
            ide_components_1.message.info('很抱歉，您并未输入任何命令，可以试试这么问：/IDE 设置主题');
            return;
        }
        // 代码区选中状况
        if (theme && selectCode && !value.trim()) {
            onSend(preText + ` \`\`\`\n ${selectCode} \n\`\`\``);
            setTheme('');
            return;
        }
        // 报错提示
        if (theme && !value.trim() && !selectCode) {
            ide_components_1.message.info('很抱歉，您并未选中或输入任何代码，请先选中或输入代码');
        }
    }, [onSend, value, agentId, command]);
    const acquireOptionsCheck = (0, react_1.useCallback)((themeValue, agentId, command) => {
        // 目前仅 ext 的 command 有 agentId，因此有 agentId，则说明是 ext 注册的
        if (agentId) {
            setIsShowOptions(false);
            setTheme('');
            setAgentId(agentId);
            setCommand(command || '');
            if (inputRef === null || inputRef === void 0 ? void 0 : inputRef.current) {
                const inputValue = inputRef.current.value;
                if (inputValue === '@' || (command && inputValue === '/')) {
                    setValue('');
                }
                setTimeout(() => { var _a; return (_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.focus(); });
            }
        }
        else if (themeValue) {
            setIsShowOptions(false);
            setAgentId('');
            setCommand('');
            // 设置 slash widget 块
            const regex = /\/\s(\w+)\s/;
            const match = themeValue.match(regex);
            if (match) {
                const keyword = match[0];
                if (optionsList.find(({ name }) => name === keyword)) {
                    setTheme(keyword);
                }
            }
            else {
                setTheme('');
            }
            if (inputRef && inputRef.current) {
                inputRef.current.focus();
                const inputValue = inputRef.current.value;
                if (inputValue.length === 1 && inputValue.startsWith('/')) {
                    setValue('');
                }
            }
        }
    }, [inputRef]);
    const optionsBottomPosition = (0, react_1.useMemo)(() => {
        const customBottom = INSTRUCTION_BOTTOM + wrapperHeight;
        if (isExpand) {
            setIsShowOptions(false);
        }
        return customBottom;
    }, [wrapperHeight]);
    const handleKeyDown = (event) => {
        var _a, _b;
        if (event.key === 'Enter' && !event.nativeEvent.isComposing) {
            if (!event.shiftKey) {
                event.preventDefault();
                handleSend();
            }
        }
        else if (event.key === 'Backspace') {
            if (((_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.selectionEnd) === 0 && ((_b = inputRef.current) === null || _b === void 0 ? void 0 : _b.selectionStart) === 0) {
                setTheme('');
                if (agentId) {
                    if (command) {
                        setCommand('');
                    }
                    else {
                        setAgentId('');
                    }
                }
            }
        }
    };
    const handleFocus = () => {
        setFocus(true);
    };
    const handleBlur = (0, react_1.useCallback)(() => {
        setFocus(false);
        setIsShowOptions(false);
    }, [inputRef]);
    const handleExpandClick = (0, react_1.useCallback)(() => {
        const expand = isExpand;
        setIsExpand(!expand);
        if (!expand) {
            const ele = document.querySelector('#ai_chat_left_container');
            // ai_chat_left_container - (padding + header_operate + border ) - theme_container - padding
            const maxHeight = ele.clientHeight - 68 - (theme ? 32 : 0) - 16;
            setWrapperHeight(maxHeight);
        }
        else {
            setWrapperHeight(defaultHeight);
            setShowExpand(false);
        }
    }, [isExpand]);
    return (react_1.default.createElement("div", { className: (0, classnames_1.default)(styles.chat_input_container, focus ? styles.active : null) },
        isShowOptions && (react_1.default.createElement("div", { ref: instructionRef },
            react_1.default.createElement(InstructionOptions, { onClick: acquireOptionsCheck, bottom: optionsBottomPosition, trigger: value, agentId: agentId }))),
        theme && react_1.default.createElement(ThemeWidget, { themeBlock: theme }),
        agentId && react_1.default.createElement(AgentWidget, { agentId: agentId, command: command }),
        showExpand && (react_1.default.createElement("div", { className: styles.expand_icon, onClick: () => handleExpandClick() },
            react_1.default.createElement(components_1.Popover, { id: 'ai_chat_input_expand', title: isExpand ? '收起' : '展开全屏' },
                react_1.default.createElement(components_1.Icon, { className: (0, classnames_1.default)(isExpand ? (0, components_1.getIcon)('unfullscreen') : (0, components_1.getIcon)('fullescreen')) })))),
        react_1.default.createElement(components_1.Input, { ref: inputRef, placeholder: placeholder, wrapperStyle: { height: wrapperHeight + 'px' }, style: {
                // 2px 额外宽度 否则会有滚动条
                height: wrapperHeight - 12 + 2 + 'px',
                // maxHeight: wrapperHeight-16 + 'px',
                // minHeight: wrapperHeight-16 + 'px',
            }, value: value, type: 'textarea', onKeyDown: handleKeyDown, onFocus: handleFocus, onBlur: handleBlur, onValueChange: handleInputChange, disabled: disabled, className: styles.input_wrapper, addonAfter: react_1.default.createElement("div", { className: styles.input_icon_container },
                react_1.default.createElement("div", { className: (0, classnames_1.default)(styles.send_chat_btn, focus && styles.active, disabled && styles.disabled, props.sendBtnClassName) }, disabled ? (react_1.default.createElement("div", { className: styles.ai_loading },
                    react_1.default.createElement("div", { className: styles.loader }),
                    react_1.default.createElement("div", { className: styles.loader }),
                    react_1.default.createElement("div", { className: styles.loader }))) : (react_1.default.createElement(components_1.Popover, { id: `ai_chat_input_send_${(0, ide_core_common_1.uuid)(4)}`, title: 'Enter 发送', disable: disabled },
                    react_1.default.createElement(ai_native_1.EnhanceIcon, { wrapperClassName: styles.send_icon, className: (0, components_1.getIcon)('send1'), onClick: () => handleSend() }))))) })));
});
//# sourceMappingURL=ChatInput.js.map