"use strict";
var InlineChatFeatureRegistry_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.InlineChatFeatureRegistry = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_common_1 = require("@opensumi/ide-core-common");
let InlineChatFeatureRegistry = InlineChatFeatureRegistry_1 = class InlineChatFeatureRegistry extends ide_core_common_1.Disposable {
    constructor() {
        super(...arguments);
        this.logger = (0, ide_core_common_1.getDebugLogger)();
        this.actionsMap = new Map();
        this.handlerMap = new Map();
        this._onActionRun = new ide_core_common_1.Emitter();
        this.onActionRun = this._onActionRun.event;
    }
    dispose() {
        super.dispose();
        this.actionsMap.clear();
        this.handlerMap.clear();
    }
    registerInlineChat(operational, handler) {
        const { id } = operational;
        if (this.actionsMap.has(id)) {
            this.logger.warn(`InlineChatFeatureRegistry: id ${id} already exists`);
            return;
        }
        this.actionsMap.set(id, operational);
        this.handlerMap.set(id, handler);
        this.disposables.push(this.commandRegistry.registerCommand({
            id: InlineChatFeatureRegistry_1.getCommandId('editor', id),
        }, {
            execute: (range) => {
                this._onActionRun.fire({
                    id,
                    range,
                });
            },
        }));
    }
    getActionButtons() {
        return Array.from(this.actionsMap.values()).filter((item) => item.renderType === 'button');
    }
    getActionMenus() {
        return Array.from(this.actionsMap.values()).filter((item) => item.renderType === 'dropdown');
    }
    getHandler(id) {
        return this.handlerMap.get(id);
    }
    getAction(id) {
        return this.actionsMap.get(id);
    }
    static getCommandId(type, id) {
        return `ai-native.inline-chat.${type}.${id}`;
    }
    getCodeActions() {
        return Array.from(this.actionsMap.keys()).map((key) => {
            const aiAction = this.actionsMap.get(key) || {};
            return {
                title: aiAction.name,
                isAI: true,
                isPreferred: true,
                kind: 'InlineChat',
                command: {
                    id: InlineChatFeatureRegistry_1.getCommandId('editor', aiAction.id),
                },
            };
        });
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_common_1.CommandRegistry),
    tslib_1.__metadata("design:type", Object)
], InlineChatFeatureRegistry.prototype, "commandRegistry", void 0);
InlineChatFeatureRegistry = InlineChatFeatureRegistry_1 = tslib_1.__decorate([
    (0, di_1.Injectable)()
], InlineChatFeatureRegistry);
exports.InlineChatFeatureRegistry = InlineChatFeatureRegistry;
//# sourceMappingURL=inline-chat.feature.registry.js.map