"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AiMarkerService = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const react_1 = tslib_1.__importDefault(require("react"));
const di_1 = require("@opensumi/di");
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const ide_editor_1 = require("@opensumi/ide-editor");
const workbench_editor_service_1 = require("@opensumi/ide-editor/lib/browser/workbench-editor.service");
const ide_file_service_1 = require("@opensumi/ide-file-service");
const markers_service_1 = require("@opensumi/ide-markers/lib/browser/markers-service");
const tree_node_defined_1 = require("@opensumi/ide-markers/lib/browser/tree/tree-node.defined");
const common_1 = require("../../common");
const ai_chat_service_1 = require("../ai-chat.service");
const styles = tslib_1.__importStar(require("./override.module.less"));
let AiMarkerService = class AiMarkerService extends markers_service_1.MarkerService {
    async handleAiIcon(node) {
        try {
            const resource = node.marker.resource;
            const message = node.marker.message;
            const { content } = await this.fileSystem.readFile(resource.toString());
            const messageWithPrompt = `代码内容是 \`\`\`\n${content.toString()}\n\`\`\`。此时有个异常问题是 "${message}", 你需要解释这个异常问题并给出修复建议`;
            this.aiChatService.launchChatMessage({
                message: `${common_1.InstructionEnum.aiExplainKey} ${node.marker.message}`,
                prompt: messageWithPrompt,
            });
        }
        catch (error) {
            throw Error('read file error', error);
        }
    }
    renderMarkerNodeIcon(component, node) {
        return (react_1.default.createElement("div", { className: (0, classnames_1.default)(!tree_node_defined_1.MarkerGroupNode.is(node) && styles.ai_marker_node_icon_container) },
            !tree_node_defined_1.MarkerGroupNode.is(node) && (react_1.default.createElement(ide_components_1.Icon, { tooltip: 'AI \u667A\u80FD\u95EE\u9898\u8BCA\u65AD', onClick: () => this.handleAiIcon(node), className: (0, classnames_1.default)((0, ide_core_browser_1.getExternalIcon)('lightbulb'), styles.ai_icon) })),
            component));
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_editor_1.WorkbenchEditorService),
    tslib_1.__metadata("design:type", workbench_editor_service_1.WorkbenchEditorServiceImpl)
], AiMarkerService.prototype, "editorService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(),
    tslib_1.__metadata("design:type", ai_chat_service_1.AiChatService)
], AiMarkerService.prototype, "aiChatService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_file_service_1.IFileServiceClient),
    tslib_1.__metadata("design:type", Object)
], AiMarkerService.prototype, "fileSystem", void 0);
AiMarkerService = tslib_1.__decorate([
    (0, di_1.Injectable)()
], AiMarkerService);
exports.AiMarkerService = AiMarkerService;
//# sourceMappingURL=ai-marker.service.js.map