"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AiMenuBarView = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const React = tslib_1.__importStar(require("react"));
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
// import { AI_RUN_DEBUG_COMMANDS } from '@opensumi/ide-core-browser/lib/ai-native/command';
const command_1 = require("@opensumi/ide-core-browser/lib/ai-native/command");
const components_1 = require("@opensumi/ide-core-browser/lib/components");
const ai_native_1 = require("@opensumi/ide-core-browser/lib/components/ai-native");
const constants_1 = require("@opensumi/ide-core-browser/lib/layout/constants");
const view_id_1 = require("@opensumi/ide-core-browser/lib/layout/view-id");
const next_1 = require("@opensumi/ide-core-browser/lib/menu/next");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const ide_main_layout_1 = require("@opensumi/ide-main-layout");
const layout_config_1 = require("../layout-config");
const styles = tslib_1.__importStar(require("./menu-bar.module.less"));
const AiMenuBarRender = () => {
    const contextmenuService = (0, ide_core_browser_1.useInjectable)(next_1.AbstractContextMenuService);
    const ctxMenuRenderer = (0, ide_core_browser_1.useInjectable)(next_1.ICtxMenuRenderer);
    const iconRef = React.useRef(null);
    const [anchor, setAnchor] = React.useState(undefined);
    React.useEffect(() => {
        if (iconRef.current) {
            const rect = iconRef.current.getBoundingClientRect();
            const { x, y, height } = rect;
            setAnchor({
                x,
                y: y + height + 4,
            });
        }
    }, [iconRef.current]);
    const extraTopMenus = React.useMemo(() => contextmenuService.createMenu({
        id: next_1.MenuId.AiMenuBarTopExtra,
    }), [contextmenuService]);
    const handleClick = React.useCallback(() => {
        if (!anchor) {
            return;
        }
        const menuNodes = extraTopMenus.getMergedMenuNodes();
        extraTopMenus.dispose();
        ctxMenuRenderer.show({
            anchor,
            menuNodes,
        });
    }, [anchor, extraTopMenus]);
    return (React.createElement(React.Fragment, null,
        React.createElement(ai_native_1.EnhanceIcon, { wrapperClassName: styles.ai_enhance_menu, className: styles.extra_top_icon, ref: iconRef, onClick: handleClick },
            React.createElement(components_1.Icon, { className: (0, classnames_1.default)((0, ide_core_browser_1.getIcon)('down'), styles.caret_icon) }))));
};
const AiMenuBarView = () => {
    const commandService = (0, ide_core_browser_1.useInjectable)(ide_core_common_1.CommandService);
    const mainLayoutService = (0, ide_core_browser_1.useInjectable)(ide_main_layout_1.IMainLayoutService);
    const aiNativeConfigService = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.AiNativeConfigService);
    const [isVisiablePanel, setIsVisiablePanel] = React.useState(false);
    // const handleRun = () => {
    //   commandService.executeCommand(AI_RUN_DEBUG_COMMANDS.id);
    // };
    const handleRightPanel = () => {
        commandService.executeCommand(command_1.AI_CHAT_PANEL_TOGGLE_VISIBLE.id);
    };
    const isVisiable = React.useCallback(() => {
        const tabbarService = mainLayoutService.getTabbarService(ide_core_browser_1.SlotLocation.left);
        return !!tabbarService.currentContainerId;
    }, [mainLayoutService]);
    React.useEffect(() => {
        requestAnimationFrame(() => {
            setIsVisiablePanel(isVisiable());
        });
    }, []);
    const MENUBAR_HEIGHT = React.useMemo(() => { var _a; return ((_a = aiNativeConfigService.appConfig.layoutViewSize) === null || _a === void 0 ? void 0 : _a.MENUBAR_HEIGHT) || constants_1.LAYOUT_VIEW_SIZE.MENUBAR_HEIGHT; }, [aiNativeConfigService]);
    const handleLeftMenuVisiable = React.useCallback(() => {
        commandService.executeCommand('main-layout.left-panel.toggle');
        requestAnimationFrame(() => {
            setIsVisiablePanel(isVisiable());
        });
    }, []);
    return (React.createElement("div", { id: view_id_1.VIEW_CONTAINERS.MENUBAR, className: styles.menu_bar_view, style: { height: MENUBAR_HEIGHT } },
        React.createElement("div", { className: styles.container },
            React.createElement("div", { className: styles.left },
                React.createElement(ai_native_1.EnhanceIcon, { wrapperClassName: styles.enhance_menu, icon: isVisiablePanel ? 'left-nav-open' : 'left-nav-close', onClick: handleLeftMenuVisiable }),
                React.createElement("span", { className: styles.dividing }),
                React.createElement("div", { className: styles.top_menus_bar },
                    React.createElement(AiMenuBarRender, null)),
                React.createElement(ide_core_browser_1.SlotRenderer, { slot: layout_config_1.AI_MENU_BAR_LEFT, flex: 1, overflow: 'initial' })),
            React.createElement("div", { className: styles.center }),
            React.createElement("div", { className: styles.right },
                React.createElement(ide_core_browser_1.SlotRenderer, { slot: layout_config_1.AI_MENU_BAR_RIGHT, flex: 1, overflow: 'initial' }),
                aiNativeConfigService.capabilities.supportsAiChatAssistant && (React.createElement("div", { className: styles.ai_switch, onClick: handleRightPanel },
                    React.createElement(ai_native_1.AILogoAvatar, { iconClassName: styles.avatar_icon_large })))))));
};
exports.AiMenuBarView = AiMenuBarView;
//# sourceMappingURL=menu-bar.view.js.map