import { CancellationToken, Event, FileType, IDisposable, IMarkdownString, Uri } from '@opensumi/ide-core-common';
import { AISerivceType } from '@opensumi/ide-core-common/lib/ai-native/reporter';
export declare const AiInlineChatContentWidget = "Ai-inline-chat-content-widget";
export declare const Ai_CHAT_CONTAINER_VIEW_ID = "ai_chat";
export declare const Ai_MENUBAR_CONTAINER_VIEW_ID = "ai_menubar";
export declare const AI_CHAT_DEFAULT_SIZE = 360;
export interface IChatMessageStructure {
    /**
     * 用于 chat 面板展示
     */
    message: string;
    /**
     * 实际调用的 prompt
     */
    prompt?: string;
    /**
     * 数据采集上报消息类型
     */
    reportType?: AISerivceType;
    agentId?: string;
    /**
     * slash command
     */
    command?: string;
    /**
     * 是否立即发送，默认为 true
     */
    immediate?: boolean;
}
/**
 * 指令 key
 */
export declare enum InstructionEnum {
    aiExplainKey = "/ Explain ",
    aiOptimzeKey = "/ Optimize ",
    aiCommentsKey = "/ Comments ",
    aiTestKey = "/ Test ",
    aiSumiKey = "/ IDE ",
    aiRunKey = "/ RUN "
}
export declare enum ChatCompletionRequestMessageRoleEnum {
    System = "system",
    User = "user",
    Assistant = "assistant"
}
export interface ChatCompletionRequestMessage {
    /**
     * The role of the author of this message.
     * @type {string}
     * @memberof ChatCompletionRequestMessage
     */
    role: ChatCompletionRequestMessageRoleEnum;
    /**
     * The contents of the message
     * @type {string}
     * @memberof ChatCompletionRequestMessage
     */
    content: string;
    /**
     * The name of the user in a multi-user chat
     * @type {string}
     * @memberof ChatCompletionRequestMessage
     */
    name?: string;
}
export declare enum AiNativeSettingSectionsId {
    INLINE_CHAT_AUTO_VISIBLE = "inlineChat.auto.visible"
}
export declare const AI_NATIVE_SETTING_GROUP_ID = "AI-Native";
export declare const IAiChatService: unique symbol;
export interface PromptOption {
    language?: string;
    useCot?: boolean;
}
export declare namespace AiResponseTips {
    const ERROR_RESPONSE = "\u5F53\u524D\u4E0E\u6211\u4E92\u52A8\u7684\u4EBA\u592A\u591A\uFF0C\u8BF7\u7A0D\u540E\u518D\u8BD5\uFF0C\u611F\u8C22\u60A8\u7684\u7406\u89E3\u4E0E\u652F\u6301";
    const STOP_IMMEDIATELY = "\u6211\u5148\u4E0D\u60F3\u4E86\uFF0C\u6709\u9700\u8981\u53EF\u4EE5\u968F\u65F6\u95EE\u6211";
    const NOTFOUND_COMMAND = "\u5F88\u62B1\u6B49\uFF0C\u6682\u65F6\u672A\u627E\u5230\u53EF\u7ACB\u5373\u6267\u884C\u7684\u547D\u4EE4\u3002";
    const NOTFOUND_COMMAND_TIP = "\u4F60\u53EF\u4EE5\u6253\u5F00\u547D\u4EE4\u9762\u677F\u641C\u7D22\u76F8\u5173\u64CD\u4F5C\u6216\u8005\u91CD\u65B0\u63D0\u95EE\u3002";
}
export declare const highLightLanguageSupport: string[];
export declare const IChatManagerService: unique symbol;
export declare const IChatAgentService: unique symbol;
export interface IChatAgentService {
    readonly onDidChangeAgents: Event<void>;
    readonly onDidSendMessage: Event<IChatContent>;
    registerAgent(agent: IChatAgent): IDisposable;
    invokeAgent(id: string, request: IChatAgentRequest, progress: (part: IChatProgress) => void, history: IChatMessage[], token: CancellationToken): Promise<IChatAgentResult>;
    getAgents(): Array<IChatAgent>;
    getAgent(id: string): IChatAgent | undefined;
    hasAgent(id: string): boolean;
    updateAgent(id: string, updateMetadata: IChatAgentMetadata): Promise<void>;
    populateChatInput(id: string, message: IChatMessageStructure): void;
    getCommands(): Array<IChatAgentCommand & {
        agentId: string;
    }>;
    parseMessage(value: string, currentAgentId?: string): {
        agentId: string;
        command: string;
        message: string;
    };
    getFollowups(id: string, sessionId: string, token: CancellationToken): Promise<IChatFollowup[]>;
    getSampleQuestions(id: string, token: CancellationToken): Promise<IChatFollowup[]>;
    getAllSampleQuestions(): Promise<IChatReplyFollowup[]>;
    getDefaultAgentId(): undefined | string;
    sendMessage(chunk: IChatContent): void;
}
export interface IChatAgent extends IChatAgentData {
    invoke(request: IChatAgentRequest, progress: (part: IChatProgress) => void, history: IChatMessage[], token: CancellationToken): Promise<IChatAgentResult>;
    provideFollowups?(sessionId: string, token: CancellationToken): Promise<IChatFollowup[]>;
    provideSlashCommands(token: CancellationToken): Promise<IChatAgentCommand[]>;
    provideSampleQuestions?(token: CancellationToken): Promise<IChatReplyFollowup[]>;
    provideChatWelcomeMessage(token: CancellationToken): Promise<undefined | IChatAgentWelcomeMessage>;
}
export interface IChatAgentData {
    id: string;
    metadata: IChatAgentMetadata;
}
export interface IChatAgentMetadata {
    description?: string;
    isDefault?: boolean;
    fullName?: string;
    icon?: Uri;
    iconDark?: Uri;
}
export interface IChatAgentRequest {
    sessionId: string;
    requestId: string;
    command?: string;
    message: string;
    regenerate?: boolean;
}
export declare const enum ChatMessageRole {
    System = 0,
    User = 1,
    Assistant = 2,
    Function = 3
}
export interface IChatMessage {
    readonly role: ChatMessageRole;
    readonly content: string;
    readonly name?: string;
}
export interface IChatContent {
    content: string;
    kind: 'content';
}
export interface IChatMarkdownContent {
    content: IMarkdownString;
    kind: 'markdownContent';
}
export interface IChatAsyncContent {
    content: string;
    resolvedContent: Promise<string | IMarkdownString | IChatTreeData>;
    kind: 'asyncContent';
}
export interface IChatProgressMessage {
    content: string;
    kind: 'progressMessage';
}
export interface IChatResponseProgressFileTreeData {
    label: string;
    uri: Uri;
    type?: FileType;
    children?: IChatResponseProgressFileTreeData[];
}
export interface IChatTreeData {
    treeData: IChatResponseProgressFileTreeData;
    kind: 'treeData';
}
export interface IChatComponent {
    component: string;
    value?: unknown;
    kind: 'component';
}
export type IChatProgress = IChatContent | IChatMarkdownContent | IChatAsyncContent | IChatTreeData | IChatComponent;
export interface IChatResponseErrorDetails {
    message: string;
}
export interface IChatAgentResult {
    errorDetails?: IChatResponseErrorDetails;
}
export interface IChatAgentCommand {
    name: string;
    description: string;
}
export interface IChatReplyFollowup {
    kind: 'reply';
    message: string;
    title?: string;
    tooltip?: string;
}
export interface IChatResponseCommandFollowup {
    kind: 'command';
    commandId: string;
    args?: any[];
    title: string;
    when?: string;
}
export type IChatFollowup = IChatReplyFollowup | IChatResponseCommandFollowup;
export interface IChatMessage {
    readonly role: ChatMessageRole;
    readonly content: string;
    readonly name?: string;
}
export interface IChatRequestMessage {
    prompt: string;
    agentId: string;
    command?: string;
}
export interface IChatRequestModel {
    readonly requestId: string;
    session: IChatModel;
    message: IChatRequestMessage;
    response: IChatResponseModel;
}
export interface IChatResponseModel {
    readonly requestId: string;
    session: IChatModel;
}
export interface IChatModel {
    readonly requests: IChatRequestModel[];
}
export type IChatWelcomeMessageContent = string | IMarkdownString;
export interface IChatAgentWelcomeMessage {
    content: IChatWelcomeMessageContent;
    sampleQuestions?: IChatReplyFollowup[];
}
export interface ISampleQuestions {
    title: string;
    message: string;
    icon?: string;
    tooltip?: string;
}
//# sourceMappingURL=index.d.ts.map